@@ -47,11 +47,11 @@ class GetCollectionIncludedEnvironment:
         self.tasks = [
             create_task(self.collection.get_collection_included(self, self.ids))
         ]
-        query_fields = self.query['fields']
-        if self.collection in query_fields:
+        fields = self.query['fields']
+        if self.collection in fields:
             self.tasks.extend([
                 create_task(rel.get_collection_included(self, self.ids))
-                for rel in query_fields[self.collection]
+                for rel in fields[self.collection]
                 if rel in self.collection.table.remote_relationships
             ])
         else:
@@ -91,11 +91,11 @@ class GetObjectIncludedEnvironment:
         self.tasks = [
             create_task(self.collection.get_object_included(self, self.ids))
         ]
-        query_fields = self.query['fields']
-        if self.collection in query_fields:
+        fields = self.query['fields']
+        if self.collection in fields:
             self.tasks.extend([
                 create_task(rel.get_object_included(self, self.ids))
-                for rel in query_fields[self.collection]
+                for rel in fields[self.collection]
                 if rel in self.collection.table.remote_relationships
             ])
         else:
