@@ -85,10 +85,26 @@ class FilterNode:
         return None
 
 
-def query_has_parameter(query, name):
-    """Checks if a query parameter exists."""
+def has_fields_query_parameter(query):
+    """Checks if a 'fields[...]' query parameter exists."""
     for parameter in query:
-        if parameter.split('%5B')[0] == name:
+        if parameter.startswith('fields%5B') and parameter.endswith('%5D'):
+            return True
+    return False
+
+
+def has_filter_query_parameter(query):
+    """Checks if a 'filter[...]' query parameter exists."""
+    for parameter in query:
+        if parameter.startswith('filter%5B') and parameter.endswith('%5D'):
+            return True
+    return False
+
+
+def has_page_query_parameter(query):
+    """Checks if a 'page[...]' query parameter exists."""
+    for parameter in query:
+        if parameter.startswith('page%5B') and parameter.endswith('%5D'):
             return True
     return False
 
@@ -96,7 +112,7 @@ def query_has_parameter(query, name):
 def parse_fields(request_query, query, errors, *, allow=False):
     """Parses the request's fields query parameter."""
 
-    if query_has_parameter(request_query, 'fields'):
+    if has_fields_query_parameter(request_query):
         if allow:
             query['fields'] = fields_dict(request_query, errors)
         else:
@@ -141,7 +157,7 @@ def fields_dict(request_query, errors):
 
 def parse_page(request_query, query, errors, *, allow=False):
     """Parses the request's page query parameter."""
-    if query_has_parameter(request_query, 'page'):
+    if has_page_query_parameter(request_query):
         if allow:
             query['page'] = page_dict(request_query, errors)
         else:
