@@ -136,9 +136,11 @@ class Table:
                                 cls.atable_def_by_class_name[col.atable] = (
                                     f"class {col.atable}(AssociationTable):\n"
                                     f"    rel0 = ManyToOneRelationship"
-                                    f"('{lclassname}', lfkey='{col.lafkey}')\n"
+                                    f"('{lclassname}', lfkey='{col.lafkey}', "
+                                    "nullable=False)\n"
                                     f"    rel1 = ManyToOneRelationship"
-                                    f"('{rclassname}', lfkey='{col.rafkey}')\n")
+                                    f"('{rclassname}', lfkey='{col.rafkey}', "
+                                    "nullable=False)\n")
                 if (isinstance(col.rtable, str) and
                         col.rtable in Table.by_class_name):
                     col.rtable = Table.by_class_name[col.rtable]
