@@ -202,37 +202,37 @@ class Object(Resource):
         data member contains something like the following object:
 
         {
-            'type': 'centers',
-            'id': '1',
-            'attributes': {
-                'attr_int': 1,
-                'attr_str': 'one',
+          'type': 'centers',
+          'id': '1',
+          'attributes': {
+            'attr_int': 1,
+            'attr_str': 'one',
+          },
+          'relationships': {
+            'one_one_local': {
+              'data': {
+                'type': 'one_one_locals',
+                'id': UUID_11,
+              },
+              'links': {
+                'self': '/resources/centers/1/relationships/one_one_local',
+                'related': '/resources/centers/1/one_one_local',
+              },
             },
-            'relationships': {
-                'one_one_local': {
-                    'data': {
-                        'type': 'one_one_locals',
-                        'id': UUID_11,
-                    },
-                    'links': {
-                        'self': '/centers/1/relationships/one_one_local',
-                        'related': '/centers/1/one_one_local',
-                    },
-                },
-                'many_one': {
-                    'data': {
-                        'type': 'many_ones',
-                        'id': UUID_31,
-                    },
-                    'links': {
-                        'self': '/centers/1/relationships/many_ones',
-                        'related': '/centers/1/many_ones',
-                    },
-                },
-            },
-            'links': {
-                'self': '/centers/1',
+            'many_one': {
+              'data': {
+                'type': 'many_ones',
+                'id': UUID_31,
+              },
+              'links': {
+                'self': '/resources/centers/1/relationships/many_ones',
+                'related': '/resources/centers/1/many_ones',
+              },
             },
+          },
+          'links': {
+            'self': '/resources/centers/1',
+          },
         }
         """
         fields = env.query['fields']
@@ -249,7 +249,7 @@ class Object(Resource):
             log.debug(f'{stmt}: {self.id.number}')
             record = await env.connection.fetchrow(stmt, self.id.number)
             if not record:
-                env.cancel()
+                env.env.cancel()
                 raise ErrorsException([ResourceNotFoundError(self.path())])
         env.data = self.record_to_data(record)
         env.event.set()
@@ -280,7 +280,7 @@ class Object(Resource):
     def path(self):
         """Creates the path to the collection."""
 
-        return f'/{self.collection.name}/{self.id.name}'
+        return f'/resources/{self.collection.name}/{self.id.name}'
 
 
 class GetObjectEnvironment:
@@ -300,6 +300,7 @@ class GetObjectEnvironment:
         self.data = None
         self.included_environments = []
         self.included = None
+        self.gather_future = None
 
     def create_data_environment(self):
         """Creates the environment for collecting the data member of the GET
@@ -339,13 +340,19 @@ class GetObjectEnvironment:
         async with self.obj.table.pool.acquire() as self.connection:
             async with self.connection.transaction():
                 self.create_tasks()
-                await gather(*self.tasks)
+                self.gather_future = gather(*self.tasks)
+                await self.gather_future
         self.data = self.data_environment.data
         if self.query['includes']:
             self.included = list(
                 chain.from_iterable(env.included_by_id.values()
                                     for env in self.included_environments))
 
+    def cancel(self):
+        """Cancels the environment."""
+
+        self.gather_future.cancel()
+
 
 class GetObjectDataEnvironment:
     """Class GetCollectionDataEnvironment is the execution environment for the
@@ -355,6 +362,7 @@ class GetObjectDataEnvironment:
     # pylint: disable=too-many-instance-attributes
 
     def __init__(self, env):
+        self.env = env
         self.obj = env.obj
         self.query = env.query
         self.tasks = []
@@ -362,6 +370,7 @@ class GetObjectDataEnvironment:
         self.connection = env.connection
         self.lock = env.lock
         self.data = None
+        self.gather_future = None
         self.event = Event()
 
     def create_tasks(self):
@@ -428,11 +437,10 @@ class PatchObjectEnvironment:
 
         async with self.obj.table.pool.acquire() as self.connection:
             async with self.connection.transaction():
+                self.create_tasks()
+                self.gather_future = gather(*self.tasks)
                 try:
-                    async with self.connection.transaction():
-                        self.create_tasks()
-                        self.gather_future = gather(*self.tasks)
-                        await self.gather_future
+                    await self.gather_future
                 except NonexistentRelationshipIdError:
                     env = VerifyRelationshipIdsEnvironment(
                         self.obj.table, self.relationships, self.connection)
@@ -460,14 +468,15 @@ def parse(request):
     try:
         collection = Collection.by_name[collection_name]
     except KeyError as exc:
-        raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')
-                              ]) from exc
+        raise ErrorsException(
+            [ResourceNotFoundError(f'/resources/{collection_name}')]) from exc
 
     try:
         id_ = IdValue(id_name)
     except ValueError as exc:
         raise ErrorsException([
-            ResourceNotFoundMalformedIdError(f'/{collection_name}/{id_name}')
+            ResourceNotFoundMalformedIdError(
+                f'/resources/{collection_name}/{id_name}')
         ]) from exc
 
     return Object(collection, id_)
