@@ -96,12 +96,13 @@ class RelatedResource(Resource):
         if record is None:
             env.cancel()
             raise ErrorsException([
-                ResourceNotFoundError(f'/{self.collection.name}/{self.id.name}')
+                ResourceNotFoundError(
+                    f'/resources/{self.collection.name}/{self.id.name}')
             ])
 
     def path(self):
         """Creates the path to the relationship."""
-        return (f'/{self.collection.name}/{self.id.name}/'
+        return (f'/resources/{self.collection.name}/{self.id.name}/'
                 f'{self.related_resource_name}')
 
 
@@ -609,21 +610,22 @@ def make_related_resource(collection_name, id_name, related_resource_name):
     try:
         collection = Collection.by_name[collection_name]
     except KeyError as exc:
-        raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')
-                              ]) from exc
+        raise ErrorsException(
+            [ResourceNotFoundError(f'/resources/{collection_name}')]) from exc
 
     try:
         id_ = IdValue(id_name)
     except ValueError as exc:
         raise ErrorsException([
-            ResourceNotFoundMalformedIdError(f'/{collection_name}/{id_name}')
+            ResourceNotFoundMalformedIdError(
+                f'/resources/{collection_name}/{id_name}')
         ]) from exc
 
     try:
         relationship = getattr(collection.table.___, related_resource_name)
     except AttributeError as exc:
         raise ErrorsException([
-            ResourceNotFoundError(f'/{collection_name}/{id_name}/'
+            ResourceNotFoundError(f'/resources/{collection_name}/{id_name}/'
                                   f'{related_resource_name}')
         ]) from exc
 
